# TableModelViews

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** | Unique identifier for the view | 
**type** | **str** | View type, where &#x27;block&#x27; represents Gantt View | 
**name** | **str** | Name of the view | 
**visible_field_ids** | **list[str]** | Available on grid views only - list of visible (non-hidden) field IDs, when requested with include query parameter | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

